==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/OAuthSpecFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface OAuthSpecFluent<A extends io.fabric8.openshift.api.model.OAuthSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToIdentityProviders(java.lang.Integer index,io.fabric8.openshift.api.model.IdentityProvider item);
  public A setToIdentityProviders(java.lang.Integer index,io.fabric8.openshift.api.model.IdentityProvider item);
  public A addToIdentityProviders(io.fabric8.openshift.api.model.IdentityProvider... items);
  public A addAllToIdentityProviders(java.util.Collection<io.fabric8.openshift.api.model.IdentityProvider> items);
  public A removeFromIdentityProviders(io.fabric8.openshift.api.model.IdentityProvider... items);
  public A removeAllFromIdentityProviders(java.util.Collection<io.fabric8.openshift.api.model.IdentityProvider> items);
  public A removeMatchingFromIdentityProviders(java.util.function.Predicate<io.fabric8.openshift.api.model.IdentityProviderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildIdentityProviders instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.IdentityProvider> getIdentityProviders();
  public java.util.List<io.fabric8.openshift.api.model.IdentityProvider> buildIdentityProviders();
  public io.fabric8.openshift.api.model.IdentityProvider buildIdentityProvider(java.lang.Integer index);
  public io.fabric8.openshift.api.model.IdentityProvider buildFirstIdentityProvider();
  public io.fabric8.openshift.api.model.IdentityProvider buildLastIdentityProvider();
  public io.fabric8.openshift.api.model.IdentityProvider buildMatchingIdentityProvider(java.util.function.Predicate<io.fabric8.openshift.api.model.IdentityProviderBuilder> predicate);
  public java.lang.Boolean hasMatchingIdentityProvider(java.util.function.Predicate<io.fabric8.openshift.api.model.IdentityProviderBuilder> predicate);
  public A withIdentityProviders(java.util.List<io.fabric8.openshift.api.model.IdentityProvider> identityProviders);
  public A withIdentityProviders(io.fabric8.openshift.api.model.IdentityProvider... identityProviders);
  public java.lang.Boolean hasIdentityProviders();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<A> addNewIdentityProvider();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<A> addNewIdentityProviderLike(io.fabric8.openshift.api.model.IdentityProvider item);
  public io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<A> setNewIdentityProviderLike(java.lang.Integer index,io.fabric8.openshift.api.model.IdentityProvider item);
  public io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<A> editIdentityProvider(java.lang.Integer index);
  public io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<A> editFirstIdentityProvider();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<A> editLastIdentityProvider();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<A> editMatchingIdentityProvider(java.util.function.Predicate<io.fabric8.openshift.api.model.IdentityProviderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTemplates instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.OAuthTemplates getTemplates();
  public io.fabric8.openshift.api.model.OAuthTemplates buildTemplates();
  public A withTemplates(io.fabric8.openshift.api.model.OAuthTemplates templates);
  public java.lang.Boolean hasTemplates();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TemplatesNested<A> withNewTemplates();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TemplatesNested<A> withNewTemplatesLike(io.fabric8.openshift.api.model.OAuthTemplates item);
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TemplatesNested<A> editTemplates();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TemplatesNested<A> editOrNewTemplates();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TemplatesNested<A> editOrNewTemplatesLike(io.fabric8.openshift.api.model.OAuthTemplates item);
  
  /**
   * This method has been deprecated, please use method buildTokenConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.TokenConfig getTokenConfig();
  public io.fabric8.openshift.api.model.TokenConfig buildTokenConfig();
  public A withTokenConfig(io.fabric8.openshift.api.model.TokenConfig tokenConfig);
  public java.lang.Boolean hasTokenConfig();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TokenConfigNested<A> withNewTokenConfig();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TokenConfigNested<A> withNewTokenConfigLike(io.fabric8.openshift.api.model.TokenConfig item);
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TokenConfigNested<A> editTokenConfig();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TokenConfigNested<A> editOrNewTokenConfig();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TokenConfigNested<A> editOrNewTokenConfigLike(io.fabric8.openshift.api.model.TokenConfig item);
  public interface IdentityProvidersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.IdentityProviderFluent<io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<N>>{
    public N and();
    public N endIdentityProvider();
    
  }
  public interface TemplatesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.OAuthTemplatesFluent<io.fabric8.openshift.api.model.OAuthSpecFluent.TemplatesNested<N>>{
    public N and();
    public N endTemplates();
    
  }
  public interface TokenConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.TokenConfigFluent<io.fabric8.openshift.api.model.OAuthSpecFluent.TokenConfigNested<N>>{
    public N and();
    public N endTokenConfig();
    
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/OAuthSpecFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface OAuthSpecFluent<A extends io.fabric8.openshift.api.model.OAuthSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToIdentityProviders(java.lang.Integer index,io.fabric8.openshift.api.model.IdentityProvider item);
  public A setToIdentityProviders(java.lang.Integer index,io.fabric8.openshift.api.model.IdentityProvider item);
  public A addToIdentityProviders(io.fabric8.openshift.api.model.IdentityProvider... items);
  public A addAllToIdentityProviders(java.util.Collection<io.fabric8.openshift.api.model.IdentityProvider> items);
  public A removeFromIdentityProviders(io.fabric8.openshift.api.model.IdentityProvider... items);
  public A removeAllFromIdentityProviders(java.util.Collection<io.fabric8.openshift.api.model.IdentityProvider> items);
  public A removeMatchingFromIdentityProviders(java.util.function.Predicate<io.fabric8.openshift.api.model.IdentityProviderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildIdentityProviders instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.IdentityProvider> getIdentityProviders();
  public java.util.List<io.fabric8.openshift.api.model.IdentityProvider> buildIdentityProviders();
  public io.fabric8.openshift.api.model.IdentityProvider buildIdentityProvider(java.lang.Integer index);
  public io.fabric8.openshift.api.model.IdentityProvider buildFirstIdentityProvider();
  public io.fabric8.openshift.api.model.IdentityProvider buildLastIdentityProvider();
  public io.fabric8.openshift.api.model.IdentityProvider buildMatchingIdentityProvider(java.util.function.Predicate<io.fabric8.openshift.api.model.IdentityProviderBuilder> predicate);
  public java.lang.Boolean hasMatchingIdentityProvider(java.util.function.Predicate<io.fabric8.openshift.api.model.IdentityProviderBuilder> predicate);
  public A withIdentityProviders(java.util.List<io.fabric8.openshift.api.model.IdentityProvider> identityProviders);
  public A withIdentityProviders(io.fabric8.openshift.api.model.IdentityProvider... identityProviders);
  public java.lang.Boolean hasIdentityProviders();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<A> addNewIdentityProvider();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<A> addNewIdentityProviderLike(io.fabric8.openshift.api.model.IdentityProvider item);
  public io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<A> setNewIdentityProviderLike(java.lang.Integer index,io.fabric8.openshift.api.model.IdentityProvider item);
  public io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<A> editIdentityProvider(java.lang.Integer index);
  public io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<A> editFirstIdentityProvider();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<A> editLastIdentityProvider();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<A> editMatchingIdentityProvider(java.util.function.Predicate<io.fabric8.openshift.api.model.IdentityProviderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTemplates instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.OAuthTemplates getTemplates();
  public io.fabric8.openshift.api.model.OAuthTemplates buildTemplates();
  public A withTemplates(io.fabric8.openshift.api.model.OAuthTemplates templates);
  public java.lang.Boolean hasTemplates();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TemplatesNested<A> withNewTemplates();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TemplatesNested<A> withNewTemplatesLike(io.fabric8.openshift.api.model.OAuthTemplates item);
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TemplatesNested<A> editTemplates();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TemplatesNested<A> editOrNewTemplates();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TemplatesNested<A> editOrNewTemplatesLike(io.fabric8.openshift.api.model.OAuthTemplates item);
  
  /**
   * This method has been deprecated, please use method buildTokenConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.TokenConfig getTokenConfig();
  public io.fabric8.openshift.api.model.TokenConfig buildTokenConfig();
  public A withTokenConfig(io.fabric8.openshift.api.model.TokenConfig tokenConfig);
  public java.lang.Boolean hasTokenConfig();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TokenConfigNested<A> withNewTokenConfig();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TokenConfigNested<A> withNewTokenConfigLike(io.fabric8.openshift.api.model.TokenConfig item);
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TokenConfigNested<A> editTokenConfig();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TokenConfigNested<A> editOrNewTokenConfig();
  public io.fabric8.openshift.api.model.OAuthSpecFluent.TokenConfigNested<A> editOrNewTokenConfigLike(io.fabric8.openshift.api.model.TokenConfig item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface IdentityProvidersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.IdentityProviderFluent<io.fabric8.openshift.api.model.OAuthSpecFluent.IdentityProvidersNested<N>>{
    public N and();
    public N endIdentityProvider();
    
  }
  public interface TemplatesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.OAuthTemplatesFluent<io.fabric8.openshift.api.model.OAuthSpecFluent.TemplatesNested<N>>{
    public N and();
    public N endTemplates();
    
  }
  public interface TokenConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.TokenConfigFluent<io.fabric8.openshift.api.model.OAuthSpecFluent.TokenConfigNested<N>>{
    public N and();
    public N endTokenConfig();
    
  }
  
}
